package at.fhooe.mc.magicwand.client.poi;

/**
 * @class POI
 * @author Maria Neumayer
 * @brief creates POIs with all important informations and implements behaviour
 */
public class POI {

    /**
     * name of the POI
     */
    private String m_name;
    /**
     * description of the POI
     */
    private String m_description;
    /**
     * link of the POI
     */
    private String m_link;
    /**
     * category of the POI
     */
    private String m_category;
    /**
     * priority of the POI
     */
    private int m_priority;
    /**
     * distance of the POI
     */
    private double m_distance;
    /**
     * group of the POI
     */
    private int m_group;

    /**
     * @fn public POI()
     * @brief structure to save result POI
     */
    public POI() {
        m_name = null;
        m_description = null;
        m_link = null;
        m_category = null;
        m_priority = 0;
        m_distance = 0.0;
        m_group = 0;
    }

    /**
     * @fn public String getM_name()
     * @brief gets the name of POI
     * @return name of POI
     */
    public String getM_name() {
        return m_name;
    }

    /**
     * @fn public void setM_name(String _name)
     * @brief sets the name of a POI
     * @param _name
     *            name of POI
     */
    public void setM_name(String _name) {
        m_name = _name;
    }

    /**
     * @fn public String getM_description()
     * @brief gets the description of POI
     * @return description of POI
     */
    public String getM_description() {
        return m_description;
    }

    /**
     * @fn public void setM_description(String _description)
     * @brief sets description of POI
     * @param _description
     *            description of POI
     */
    public void setM_description(String _description) {
        m_description = _description;
    }

    /**
     * @fn public String getM_link()
     * @brief gets link of POI
     * @return link of POI
     */
    public String getM_link() {
        return m_link;
    }

    /**
     * @fn public void setM_link(String _link)
     * @brief sets link of POI
     * @param _link
     *            link of POI
     */
    public void setM_link(String _link) {
        m_link = _link;
    }

    /**
     * @fn public int getM_priority()
     * @brief gets priority ofPOI
     * @return priority of POI
     */
    public int getM_priority() {
        return m_priority;
    }

    /**
     * @fn public void setM_priority(int _priority)
     * @brief sets priority of POI
     * @param _priority
     *            priority of POI
     */
    public void setM_priority(int _priority) {
        m_priority = _priority;
    }

    /**
     * @fn public double getM_distance()
     * @brief gets distance of POI
     * @return distance of POI
     */
    public double getM_distance() {
        return m_distance;
    }

    /**
     * @fn public void setM_distance(double _distance)
     * @brief sets distance of POI
     * @param _distance
     *            distance of POI
     */
    public void setM_distance(double _distance) {
        m_distance = _distance;
    }

    /**
     * @fn public String getM_category()
     * @brief gets category of POI
     * @return category of POI
     */
    public String getM_category() {
        return m_category;
    }

    /**
     * @fn public void setM_category(String _category)
     * @brief sets category of POI
     * @param _category
     *            category of POI
     */
    public void setM_category(String _category) {
        m_category = _category;
    }

    /**
     * @fn public int getM_group()
     * @brief gets group of POI
     * @return priority group of POI
     */
    public int getM_group() {
        return m_group;
    }

    /**
     * @fn public void setM_group(int _group)
     * @brief sets group of POI
     * @param _group
     *            priority group of POI
     */
    public void setM_group(int _group) {
        m_group = _group;
    }

    /**
     * @fn public POI clone()
     * @brief makes a copy of a POI
     * @return copy of POI
     */
    public POI clone() {
        POI clone = new POI();
        clone.setM_name(m_name);
        clone.setM_description(m_description);
        clone.setM_link(m_link);
        clone.setM_category(m_category);
        clone.setM_distance(m_distance);
        clone.setM_priority(m_priority);
        clone.setM_group(m_group);
        return clone;

    }

    /**
     * @fn public void print()
     * @brief prints out the POI for testing
     */
    public void print() {
        System.out.println(m_name);
        System.out.println(m_description);
        System.out.println(m_link);
        System.out.println(m_category);
        System.out.println(m_distance);
        System.out.println(m_priority);
        System.out.println(m_group);
        System.out.println("");
    }
}
